PALM-meteo: palmmeteo.dispatch Namespace Reference

PALM-meteo

Loading...
Searching...
No Matches
Functions | Variables
palmmeteo.dispatch Namespace Reference

## Functions
| threading_excepthook (args)
| build_exec_queue (event, from_plugins)
| execute_event (event, from_plugins)
| run (argv)
| main ()

## Variables
list | last_stage_files = []

## Function Documentation

## ◆ build_exec_queue()

palmmeteo.dispatch.build_exec_queue | ( |  | event,
|  |  | from_plugins
| ) |  |

## ◆ execute_event()

palmmeteo.dispatch.execute_event | ( |  | event,
|  |  | from_plugins
| ) |  |

## ◆ main()

palmmeteo.dispatch.main | ( |  | ) |

## ◆ run()

palmmeteo.dispatch.run | ( |  | argv | ) |

## ◆ threading_excepthook()

palmmeteo.dispatch.threading_excepthook | ( |  | args | ) |

    Overwrites original threading.excepthook to terminate after unhandled error.

## Variable Documentation

## ◆ last_stage_files

list palmmeteo.dispatch.last_stage_files = []